mocks

package
v0.15.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ErrorRegistry

type ErrorRegistry struct {
	mock.Mock
}

ErrorRegistry is an autogenerated mock type for the ErrorRegistry type

func NewErrorRegistry

func NewErrorRegistry(t interface {
	mock.TestingT
	Cleanup(func())
}) *ErrorRegistry

NewErrorRegistry creates a new instance of ErrorRegistry. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*ErrorRegistry) EXPECT

func (_m *ErrorRegistry) EXPECT() *ErrorRegistry_Expecter

func (*ErrorRegistry) Lookup

func (_mock *ErrorRegistry) Lookup(err error) (errmap.Result, bool)

Lookup provides a mock function for the type ErrorRegistry

func (*ErrorRegistry) Register

func (_mock *ErrorRegistry) Register(err error, status int, response errorResponses.ErrorResponse)

Register provides a mock function for the type ErrorRegistry

type ErrorRegistry_Expecter

type ErrorRegistry_Expecter struct {
	// contains filtered or unexported fields
}

func (*ErrorRegistry_Expecter) Lookup

func (_e *ErrorRegistry_Expecter) Lookup(err interface{}) *ErrorRegistry_Lookup_Call

Lookup is a helper method to define mock.On call

  • err error

func (*ErrorRegistry_Expecter) Register

func (_e *ErrorRegistry_Expecter) Register(err interface{}, status interface{}, response interface{}) *ErrorRegistry_Register_Call

Register is a helper method to define mock.On call

  • err error
  • status int
  • response errorResponses.ErrorResponse

type ErrorRegistry_Lookup_Call

type ErrorRegistry_Lookup_Call struct {
	*mock.Call
}

ErrorRegistry_Lookup_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Lookup'

func (*ErrorRegistry_Lookup_Call) Return

func (*ErrorRegistry_Lookup_Call) Run

func (*ErrorRegistry_Lookup_Call) RunAndReturn

func (_c *ErrorRegistry_Lookup_Call) RunAndReturn(run func(err error) (errmap.Result, bool)) *ErrorRegistry_Lookup_Call

type ErrorRegistry_Register_Call

type ErrorRegistry_Register_Call struct {
	*mock.Call
}

ErrorRegistry_Register_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Register'

func (*ErrorRegistry_Register_Call) Return

func (*ErrorRegistry_Register_Call) Run

func (*ErrorRegistry_Register_Call) RunAndReturn

func (_c *ErrorRegistry_Register_Call) RunAndReturn(run func(err error, status int, response errorResponses.ErrorResponse)) *ErrorRegistry_Register_Call

Jump to